# Google Palm 2
- [Google PaLM 2](https://blog.google/technology/ai/google-palm-2-ai-large-language-model/)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Quick Start Guide
### Update your agent settings
1. Set `AI_PROVIDER` to `palm`.
2. Set `PALM_API_KEY` to your Google PaLM 2 API key.